@@ -75,7 +75,7 @@ class BaseTest(unittest.TestCase):
         return clean_up_result
 
 
-class TestType(Enum):
+class TypeOfTest(Enum):
     PUBLIC = 'Public'
     FUNCTIONAL = 'Functional'
     SIGNAL = 'Signal'
@@ -85,7 +85,7 @@ class ScoredTest(BaseTest):
 
     def __init__(self, method_name='runTest'):
         super().__init__(method_name)
-        self.test_type = TestType.PUBLIC
+        self.test_type = TypeOfTest.PUBLIC
         self.test_weight = 0
         self.test_signal = None
 
